============
Installation
============

Prerequisite
============

- UNIX-like OS
    - Windows is not supported
- Python >= 3.4
- `Jupyter Notebook`_ >= 5.0
- Tornado_ >= 4.5, < 5

Jupyter Notebook and Tornado will be installed automatically if they do not exist in your environment. Tornado 5 is not yet supported.

.. _`Jupyter Notebook`: https://jupyter.org/
.. _`Tornado`: http://www.tornadoweb.org/

Installation
============

.. code-block:: sh

    $ pip install jaffle

You will also probably need pytest:

.. code-block:: sh

    $ pip install pytest
